# Contribution Guidelines

Please note that this project is released with a [Contributor Code of Conduct](code-of-conduct.md). By participating in this project you agree to abide by its terms.

---

Ensure your pull request adheres to the following guidelines:

- **The pull request should have a useful title and include a link to the thing you're submitting and why it should be included.**
- If you just created something, wait at least 30 days before submitting.
- Search previous suggestions before making a new one, as yours may be a duplicate.
- If you're submitting a closed source app, include evidence of it being built with Electron.
- The "Closed Source" section has a very high bar for acceptance. You're at lot more likely to get accepted if you link to a blog post on how you built the app. Don't worry if your submission is declined, you can still submit your app to the [official Electron apps list](http://electron.atom.io/apps/).
- Submitted open source apps should have a English readme, screenshot of the app in the readme, and a binary for at least one OS, preferably macOS, Linux and Windows.
- Submitted packages should be tested and documented.
- Make an individual pull request for each suggestion.
- Use the following format: `[title](link) - Description.`
- Additions should be added to the bottom of the relevant section.
- Keep descriptions short and simple, but descriptive.
- Start the description with a capital and end with a full stop/period.
- Don't mention `Electron` in the description as it's implied.
- Don't start the description with `A` or `An`.
- Check your spelling and grammar.
- Make sure your text editor is set to remove trailing whitespace.
- New categories or improvements to the existing categorization are welcome, but should be done in a separate pull request.

Thank you for your suggestion!

### Updating your PR

A lot of times, making a PR adhere to the standards above can be difficult. If the maintainers notice anything that we'd like changed, we'll ask you to edit your PR before we merge it. If you're not sure how to do that, [here is a guide](https://github.com/RichardLitt/docs/blob/master/amending-a-commit-guide.md) on the different ways you can update your PR so that we can merge it.


### Building and Publishing the npm Package

```
git fetch
git checkout npm-module
git rebase master
npm run build
git add awesome.json
git commit -m "update awesome.json"
npm version minor -m "awesome new stuff"
npm publish
```
